@@ -5,7 +5,7 @@ from .Copula import *
 # from .dy_dx import *
 from .FSD import *
 
-# from .Internal_Functions import *
+from . import Internal_Functions
 from .LPM_UPM_VaR import *
 from .NNS_term_matrix import *
 from .Numerical_Differentiation import *
@@ -15,4 +15,4 @@ from .SSD import *
 from .TSD import *
 from .Uni_SD_Routines import *
 
-__version__ = "0.1.6"
+__version__ = "0.1.7"
